########################
PassportElementErrorType
########################


.. automodule:: litegram.enums.passport_element_error_type
    :members:
    :member-order: bysource
    :undoc-members: True
